Method: EmailHelpers#current_email_address
- Defined in:
- lib/generators/faalis/templates/features/step_definitions/email_steps.rb
#current_email_address ⇒ Object
28 29 30 31 32 33 |
# File 'lib/generators/faalis/templates/features/step_definitions/email_steps.rb', line 28 def current_email_address # Replace with your a way to find your current email. e.g @current_user.email # last_email_address will return the last email address used by email spec to find an email. # Note that last_email_address will be reset after each Scenario. last_email_address || "[email protected]" end |